# img2zarr

[![PyPI Badge](https://img.shields.io/pypi/v/img2zarr.svg)](https://pypi.python.org/pypi/img2zarr)
[![Travis Status](https://img.shields.io/travis/hubmapconsortium/img2zarr.svg)](https://travis-ci.com/hubmapconsortium/img2zarr)

Python package for converting images to zarr chunked arrays.


* Free software: MIT license
* Documentation: https://img2zarr.readthedocs.io.



